@@ -1,4 +1,6 @@
 import collections
+import inspect
+import warnings
 
 import numpy as np
 
@@ -61,5 +63,18 @@ def to_odds(p):
 
 
 def to_log_odds(p):
-    odds = to_odds(p)
-    return np.nan_to_num(np.log10(odds))
+    with np.errstate(divide='ignore'):
+        complement = 1 - p
+        return np.log10(p) - np.log10(complement)
+
+
+def from_log_odds_to_probability(log_odds):
+    return to_probability(10 ** log_odds)
+
+
+def ln_to_log10(ln_data):
+    return np.log10(np.e) * ln_data
+
+
+def warn_deprecated():
+    warnings.warn(f'the function `{inspect.stack()[1].function}` is no longer maintained; please check documentation for alternatives')
